'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _pouchdb = require('pouchdb');

var _pouchdb2 = _interopRequireDefault(_pouchdb);

var _splitTorrentRelease = require('split-torrent-release');

var _splitTorrentRelease2 = _interopRequireDefault(_splitTorrentRelease);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var db = undefined;

function Model(createId) {
	this.createId = createId;
};

Model.prototype.on404 = function (err, fn) {
	if (err.status === 404) {
		return fn();
	} else {
		throw err;
	}
};

Model.prototype.get = function (id) {
	return db.get(this.createId(id));
};

Model.prototype.put = function (id, data) {
	var doc = _extends({}, data, {
		_id: this.createId(id),
		updatedAt: new Date().toISOString()
	});

	return db.put(doc).then(function () {
		return doc;
	});
};

Model.prototype.update = function (id, data) {
	var _this = this;

	return this.get(id).then(function (dbData) {
		return _this.put(id, _extends({}, dbData, data));
	}, function (err) {
		return _this.on404(err, function () {
			return _this.put(id, data);
		});
	});
};

exports.default = function (dbPath) {
	db = new _pouchdb2.default(dbPath);

	var fileId = function fileId(file) {
		return 'file:' + file.replace('\W', '');
	};
	var prefixId = function prefixId(prefix) {
		return 'prefix:' + prefix;
	};

	var File = new Model(fileId);
	var Prefix = new Model(prefixId);

	var updateFile = File.update.bind(File);
	var getFile = File.get.bind(File);
	var getPrefix = Prefix.get.bind(Prefix);

	var getFiles = function getFiles(files) {
		return db.allDocs({
			include_docs: true,
			keys: files.map(function (file) {
				return fileId(file);
			})
		});
	};

	var getPrefixes = function getPrefixes(files) {
		return db.allDocs({
			include_docs: true,
			keys: files.map(function (file) {
				return prefixId(file.recognition.title);
			})
		});
	};

	var addFile = function addFile(file, data) {
		var parts = file.split('/');
		var filename = parts[parts.length - 1];

		var recognition = (0, _splitTorrentRelease2.default)(filename);

		return File.update(file, data).then(function () {
			return Prefix.update(recognition.title, data);
		});
	};

	return {
		fileId: fileId,
		addFile: addFile,
		getFile: getFile,
		getFiles: getFiles,
		prefixId: prefixId,
		getPrefix: getPrefix,
		getPrefixes: getPrefixes,
		updateFile: updateFile
	};
};
//# sourceMappingURL=db.js.map