'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _globby = require('globby');

var _globby2 = _interopRequireDefault(_globby);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _splitTorrentRelease = require('split-torrent-release');

var _splitTorrentRelease2 = _interopRequireDefault(_splitTorrentRelease);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var exts = '(mkv|mp4|avi)';

exports.default = function (db, rootDir) {
	return (0, _globby2.default)(['**/*.+' + exts], { cwd: rootDir, realpath: true }).then(parseVideoFiles.bind(null, db)).then(flattenVideos.bind(null, rootDir));
};

function parseVideoFiles(db, allVideos) {
	var videos = allVideos.filter(function (item) {
		return !/\.sample\./i.test(item);
	});

	var media = videos.map(function (video) {
		var data = video.split('/');

		var media = {
			file: video,
			dir: data.slice(0, data.length - 1).join('/'),
			fileName: data[data.length - 1],
			dirName: data[data.length - 2],
			birthtime: _fs2.default.statSync(video).birthtime
		};

		media.recognition = (0, _splitTorrentRelease2.default)(media.fileName || media.dirName);
		return media;
	});

	return _bluebird2.default.all([db.getFiles(videos), db.getPrefixes(media.filter(function (_) {
		return !!_.recognition;
	}))]).then(setupDb.bind(null, db, media));
};

function setupDb(db, media, _ref) {
	var _ref2 = _slicedToArray(_ref, 2);

	var dbFiles = _ref2[0];
	var dbPrefixes = _ref2[1];

	return media.map(function (media) {
		media.db = (dbFiles.rows.find(function (file) {
			return file.doc && file.doc._id === db.fileId(media.file);
		}) || {}).doc;

		if (media.recognition) {
			var prefix = (dbPrefixes.rows.find(function (prefix) {
				return prefix.doc && prefix.doc._id === db.prefixId(media.recognition.title);
			}) || {}).doc;

			if (prefix) {
				media.db = media.db || {};

				var copy = function copy(field, value) {
					if (!media.db[field]) {
						media.db[field] = value;
					}
				};

				copy('type', prefix.type);
				copy('imdb', prefix.imdb);
				copy('title', prefix.title);
				copy('s', media.recognition.s);
				copy('ep', media.recognition.ep);
			}
		}

		return media;
	});
};

function flattenVideos(rootDir, result) {
	var grouped = _lodash2.default.groupBy(result, 'dir');
	var topLevel = grouped[rootDir] || [];
	var media = _lodash2.default.map(grouped, function (media, dir) {
		return { media: media, dir: dir };
	}).filter(function (_ref3) {
		var dir = _ref3.dir;
		return dir !== rootDir;
	}).concat(topLevel.map(function (media) {
		return { media: [media], dir: media.dir };
	}));

	var cmpNames = function cmpNames(a, b) {
		if (a.fileName < b.fileName) {
			return 1;
		} else if (a.fileName > b.fileName) {
			return -1;
		} else {
			return 0;
		}
	};

	media.sort(function (a, b) {
		a.media.sort(cmpNames);
		b.media.sort(cmpNames);

		var mA = _lodash2.default.max(a.media.map(function (a) {
			return a.birthtime.getTime();
		}));
		var mB = _lodash2.default.max(b.media.map(function (b) {
			return b.birthtime.getTime();
		}));

		return mB - mA;
	});

	media.forEach(function (dirObj) {
		var media = dirObj.media[0];

		if (media.db && media.db.s) {
			var title = media.db.title + ' season ' + media.db.s;
			var scrobble = _lodash2.default.sum(_lodash2.default.pluck(dirObj.media, 'scrobble'));

			dirObj.summary = title + ' (' + scrobble + ' / ' + dirObj.media.length + ')';
			dirObj.watched = scrobble === dirObj.media.length;
		} else {
			var title = media.recognition && media.recognition.title || media.fileName;
			dirObj.summary = title + ' ' + (dirObj.media.length > 1 ? '( 0 / ' + dirObj.media.length + ')' : '');
		}
	});

	return media;
};
//# sourceMappingURL=find-files.js.map