'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _nodeNotifier = require('node-notifier');

var _nodeNotifier2 = _interopRequireDefault(_nodeNotifier);

var _storage = require('./../storage');

var _storage2 = _interopRequireDefault(_storage);

var _constants = require('./../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var notify = function notify(message) {
  _nodeNotifier2.default.notify({
    title: 'MOCK PLAYER',
    message: message
  });
};

var loopInterval = undefined;

var pausePlaying = function pausePlaying() {
  if (loopInterval) {
    clearInterval(loopInterval);
  }
};

exports.default = function (trakt, addToHistory, db, media, file, prevPosition) {
  pausePlaying();

  return _bluebird2.default.resolve().then(function () {
    var position = 0;
    var duration = 100 * 60 * 1000 * 1000; // 100 minutes
    var status = _constants.PLAYING;

    var getInfo = function getInfo() {
      return {
        progress: position / duration * 100,
        position: position,
        duration: duration,
        media: media,
        status: status
      };
    };

    var emitUpdate = function emitUpdate() {
      return _storage2.default.emit(_constants.UPDATE_PLAYBACK, getInfo());
    };

    var startPlaying = function startPlaying() {
      pausePlaying();

      loopInterval = setInterval(function () {
        position = position + 1000 * 1000; // 1 second
        emitUpdate();
      }, 1000);
    };

    startPlaying();
    notify('START PLAYING ' + file + ' ' + (prevPosition ? 'from ' + prevPosition : ''));

    var onPause = function onPause() {
      if (status === _constants.PLAYING) {
        status = _constants.PAUSED;
        pausePlaying();
      } else {
        status = _constants.PLAYING;
        startPlaying();
      }

      notify('NEW STATUS ' + status);

      emitUpdate();
    };

    _storage2.default.on(_constants.USER_PAUSE_MEDIA, onPause);

    var onClose = function onClose() {
      status = _constants.STOPPED;
      pausePlaying();

      emitUpdate();
      _storage2.default.emit(_constants.STOP_PLAYBACK, getInfo());

      notify('CLOSE MEDIA');

      _storage2.default.removeListener(_constants.USER_PAUSE_MEDIA, onPause);
      _storage2.default.removeListener(_constants.USER_CLOSE, onClose);
    };

    _storage2.default.on(_constants.USER_CLOSE, onClose);

    return { getInfo: getInfo };
  });
};
//# sourceMappingURL=mock-player.js.map