'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _fkill = require('fkill');

var _fkill2 = _interopRequireDefault(_fkill);

var _exitHook = require('exit-hook');

var _exitHook2 = _interopRequireDefault(_exitHook);

var _omxplayer = require('./../vendor/omxplayer');

var _omxplayer2 = _interopRequireDefault(_omxplayer);

var _storage = require('./../storage');

var _storage2 = _interopRequireDefault(_storage);

var _constants = require('./../constants');

var _x = require('./../x11');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var omxplayer = null;

var killProcess = function killProcess() {
	(0, _x.unregisterKeys)();
	return (0, _fkill2.default)('omxplayer.bin').then(function () {
		return console.log('success');
	}, function (err) {
		return console.log(err);
	});
};

(0, _exitHook2.default)(killProcess);

_storage2.default.on(_constants.USER_KEY_PRESS, function (key) {
	if (omxplayer) {
		omxplayer._omxProcess.stdin.write(key);
	}
});

var tr = function tr(h) {
	return h < 10 ? '0' + h : '' + h;
};

exports.default = function (trakt, addToHistory, db, media, file, prevPosition) {
	return killProcess().then(_x.registerKeys).then(function () {
		var configuration = {
			omxPlayerParams: ['--no-osd']
		};

		if (prevPosition) {
			var seconds = prevPosition / 1000 / 1000;
			var positionTime = tr(seconds / 60 / 60 | 0) + ':' + tr(seconds / 60 | 0) + ':' + tr(seconds % 60 | 0);

			configuration.omxPlayerParams.concat(['--pos', positionTime]);
		}

		omxplayer = new _omxplayer2.default(configuration);

		var duration = 0;
		var position = 0;
		var status = undefined;

		var progress = function progress() {
			return position / duration * 100;
		};

		var getInfo = function getInfo() {
			return {
				progress: progress(),
				position: position,
				duration: duration,
				status: status,
				media: media
			};
		};

		var emitUpdate = function emitUpdate() {
			return _storage2.default.emit(_constants.UPDATE_PLAYBACK, getInfo());
		};

		var emitPlay = function emitPlay() {
			trakt.startScrobble(media, progress());
			emitUpdate();
		};

		var emitPause = function emitPause() {
			trakt.pauseScrobble(media, progress());
			emitUpdate();
		};

		var emitStop = function emitStop() {
			trakt.pauseScrobble(media, progress());
			emitUpdate();
			_storage2.default.emit(_constants.STOP_PLAYBACK);
		};

		omxplayer.start(file, function (err) {
			if (err) {
				console.log(err);
			}

			setTimeout(emitPlay, 1000);
		});

		omxplayer.on('prop:Duration', function (_duration) {
			duration = _duration;
		});

		var positionCount = 0;

		omxplayer.on('prop:Position', function (_position) {
			position = _position;
			emitUpdate();

			if (positionCount % 10 === 0) {
				db.updateFile(file, { position: position, duration: duration }).then(function (res) {
					var pos = position / duration * 100;

					if (!res.scrobble && pos !== Infinity && pos > 80) {
						addToHistory(file, media);
					}
				});
			}

			positionCount = (positionCount + 1) % 10;
		});

		omxplayer.on('prop:PlaybackStatus', function (omxStatus) {
			if (omxStatus === 'Playing') {
				status = _constants.PLAYING;
				emitPlay();
			} else if (omxStatus === 'Paused') {
				status = _constants.PAUSED;
				emitPause();
			}
		});

		omxplayer.on('stopped', function () {
			status = _constants.STOPPED;
			emitStop();
			killProcess();
		});

		return { getInfo: getInfo };
	});
};
//# sourceMappingURL=omx.js.map