'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _findFiles = require('./../find-files');

var _findFiles2 = _interopRequireDefault(_findFiles);

var _nodeCache = require('node-cache');

var _nodeCache2 = _interopRequireDefault(_nodeCache);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var traktCache = new _nodeCache2.default({ stdTTL: 60 * 10 }); // invalidates in 10 mins

exports.default = function (MEDIA_PATH, db, trakt, play) {
  var router = _express2.default.Router();
  var player = undefined;

  var addToHistory = function addToHistory(filename, media) {
    return trakt.addToHistory(media).then(function () {
      return db.updateFile(filename, {
        scrobble: true,
        scrobbleAt: new Date().toISOString()
      });
    });
  };

  router.get('/api/v1/files', function (req, res, next) {
    (0, _findFiles2.default)(db, MEDIA_PATH).then(function (_) {
      return res.json(_);
    }).catch(function (err) {
      return next(err);
    });
  });

  router.get('/api/v1/playback/status', function (req, res) {
    if (player) {
      res.json(player.getInfo());
    } else {
      res.json({ status: null });
    }
  });

  router.post('/api/v1/playback/start', function (req, res) {
    db.addFile(req.body.filename, req.body.media);

    play(trakt, addToHistory, db, req.body.media, req.body.filename, req.body.position).then(function (_player) {
      return player = _player;
    });

    res.json({ status: 'ok' });
  });

  router.post('/api/v1/playback/info', function (req, res, next) {
    db.addFile(req.body.filename, req.body.media).then(function () {
      return res.json({ status: 'ok ' });
    }).catch(function (err) {
      return next(err);
    });
  });

  router.post('/api/v1/files/scrobble', function (req, res, next) {
    addToHistory(req.body.filename, req.body.media).then(function () {
      return res.json({ status: 'ok' });
    }).catch(function (err) {
      return next(err);
    });
  });

  router.post('/api/v1/files/hidden', function (req, res, next) {
    db.updateFile(req.body.file, {
      hidden: true,
      title: req.body.filename
    }).then(function () {
      return res.json({ status: 'ok' });
    }).catch(function (err) {
      return next(err);
    });
  });

  var formatSuggestion = function formatSuggestion(media) {
    return {
      value: media.ids.imdb,
      label: media.title + ' (' + media.year + ')'
    };
  };

  router.get('/api/v1/suggestions', function (req, res) {
    trakt.search(req.query.title, req.query.type).then(function (data) {
      res.json(data.map(function (media) {
        return formatSuggestion(media[req.query.type]);
      }));
    }).catch(function () {
      return res.json([]);
    });
  });

  var withCache = function withCache(key, promiseFn) {
    return function (req, res, next) {
      var data = traktCache.get(key);

      if (data) {
        res.json(data);
      } else {
        promiseFn().then(function (response) {
          res.json(response);
          traktCache.set(key, response);
        }).catch(function (err) {
          return next(err);
        });
      }
    };
  };

  var REPORT_CACHE = 'REPORT_CACHE';
  router.get('/api/v1/report', withCache(REPORT_CACHE, trakt.getReport.bind(trakt)));

  return router;
};
//# sourceMappingURL=index.js.map