'use strict';

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _morgan = require('morgan');

var _morgan2 = _interopRequireDefault(_morgan);

var _bodyParser = require('body-parser');

var _bodyParser2 = _interopRequireDefault(_bodyParser);

var _cors = require('cors');

var _cors2 = _interopRequireDefault(_cors);

var _storage = require('./storage');

var _storage2 = _interopRequireDefault(_storage);

var _db = require('./db');

var _db2 = _interopRequireDefault(_db);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _socket = require('socket.io');

var _socket2 = _interopRequireDefault(_socket);

var _traktUtils = require('trakt-utils');

var _traktUtils2 = _interopRequireDefault(_traktUtils);

var _child_process = require('child_process');

var _chokidar = require('chokidar');

var _chokidar2 = _interopRequireDefault(_chokidar);

var _userHome = require('user-home');

var _userHome2 = _interopRequireDefault(_userHome);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _constants = require('./constants');

var _index = require('./routes/index');

var _index2 = _interopRequireDefault(_index);

var _screenshots = require('./routes/screenshots');

var _screenshots2 = _interopRequireDefault(_screenshots);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getPath = function getPath(variable, homeFolder) {
	var result = process.env[variable] || _userHome2.default + homeFolder;
	_mkdirp2.default.sync(result);

	return result;
};

var MEDIA_PATH = getPath('MEDIA_PATH', '/Downloads');
var DB_PATH = getPath('DB_PATH', '/media-center-db');
var SCREENSHOTS_PATH = getPath('SCREENSHOTS_PATH', '/media-center-screenshots');

var PORT = process.env.PORT || 3000;
var TRAKT_TOKEN = process.env.TRAKT_TOKEN;

var traktId = '412681ab85026009c32dc6e525ba6226ff063aad0c1a374def0c8ee171cf121f';
var traktSecret = '714f0cb219791a0ecffec788fd7818c601397b95b2b3e8f486691366954902fb';
var trakt = new _traktUtils2.default(traktId, traktSecret, TRAKT_TOKEN);

var db = (0, _db2.default)(DB_PATH + '/' + 'db');
var app = (0, _express2.default)();

app.use(_bodyParser2.default.urlencoded({ extended: false, limit: '50mb' }));
app.use(_bodyParser2.default.json({ limit: '50mb' }));

app.use((0, _morgan2.default)('request: :remote-addr :method :url :status'));
app.use(_express2.default.static('public'));
app.use('/screenshots', _express2.default.static(SCREENSHOTS_PATH));
app.use((0, _cors2.default)());

var play = undefined;

if (process.env.NODE_ENV === 'production') {
	play = require('./players/omx').default;
} else {
	play = require('./players/mock-player').default;
}

_storage2.default.on(_constants.USER_SCREENSHOT, function () {
	// https://github.com/info-beamer/tools/tree/master/screenshot
	(0, _child_process.exec)('DISPLAY=:0 /home/pi/tools/screenshot/screenshot > ' + SCREENSHOTS_PATH + '/' + new Date().toISOString() + '.jpg');
});
_storage2.default.on(_constants.USER_SCREEN_OFF, function () {
	(0, _child_process.exec)('DISPLAY=:0 xset dpms force suspend');
});
_storage2.default.on(_constants.USER_OPEN_BROWSER, function () {
	(0, _child_process.exec)('DISPLAY=:0 xdg-open "http://localhost:' + PORT + '/" &');
});

app.use('/', (0, _index2.default)(MEDIA_PATH, db, trakt, play));
app.use('/', (0, _screenshots2.default)(SCREENSHOTS_PATH));

app.use(function (err, req, res, next) {
	if (!err) {
		next();
		return;
	}

	console.log(err, err.stack);
	res.json({ error: err.stack });
});

var http = _http2.default.Server(app);
var io = (0, _socket2.default)(http);

var lastPlaybackStatus = undefined;

io.on('connection', function (socket) {
	socket.emit(_constants.UPDATE_PLAYBACK, lastPlaybackStatus);

	socket.on(_constants.USER_PAUSE_MEDIA, function () {
		return _storage2.default.emit(_constants.USER_KEY_PRESS, _constants.OMX_KEYS.pause);
	});
	socket.on(_constants.USER_CLOSE, function () {
		return _storage2.default.emit(_constants.USER_KEY_PRESS, _constants.OMX_KEYS.stop);
	});
});

_storage2.default.on(_constants.UPDATE_PLAYBACK, function (data) {
	lastPlaybackStatus = data;
	io.emit(_constants.UPDATE_PLAYBACK, data);
});

_storage2.default.on(_constants.STOP_PLAYBACK, function (data) {
	lastPlaybackStatus = data;
	io.emit(_constants.RELOAD_FILES);
});

_chokidar2.default.watch(MEDIA_PATH, {
	ignored: /\.part$/,
	persistent: true,
	ignoreInitial: true
}).on('all', function () {
	io.emit(_constants.RELOAD_FILES);
});

http.listen(PORT, function () {
	console.log('listen localhost:' + PORT);
});
//# sourceMappingURL=server.js.map