'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _findFiles = require('./../find-files');

var _findFiles2 = _interopRequireDefault(_findFiles);

exports['default'] = function (MEDIA_PATH, db, trakt, play) {
  var router = _express2['default'].Router();
  var player = undefined;

  var addToHistory = function addToHistory(filename, media) {
    return trakt.addToHistory(media).then(function () {
      return db.updateFile(filename, {
        scrobble: true,
        scrobbleAt: new Date().toISOString()
      });
    });
  };

  router.get('/api/v1/files', function (req, res, next) {
    (0, _findFiles2['default'])(db, MEDIA_PATH).then(function (_) {
      return res.json(_);
    })['catch'](function (err) {
      return next(err);
    });
  });

  router.get('/api/v1/playback/status', function (req, res) {
    if (player) {
      res.json(player.getInfo());
    } else {
      res.json({ status: null });
    }
  });

  router.post('/api/v1/playback/start', function (req, res) {
    db.addFile(req.body.filename, req.body.media);

    play(trakt, addToHistory, db, req.body.media, req.body.filename, req.body.position).then(function (_player) {
      return player = _player;
    });

    res.json({ status: 'ok' });
  });

  router.post('/api/v1/playback/info', function (req, res, next) {
    db.addFile(req.body.filename, req.body.media).then(function () {
      return res.json({ status: 'ok ' });
    })['catch'](function (err) {
      return next(err);
    });
  });

  router.post('/api/v1/files/scrobble', function (req, res, next) {
    addToHistory(req.body.filename, req.body.media).then(function () {
      return res.json({ status: 'ok' });
    })['catch'](function (err) {
      return next(err);
    });
  });

  router.post('/api/v1/files/hidden', function (req, res, next) {
    db.updateFile(req.body.filename, { hidden: true }).then(function () {
      return res.json({ status: 'ok' });
    })['catch'](function (err) {
      return next(err);
    });
  });

  var formatSuggestion = function formatSuggestion(media) {
    return {
      value: media.ids.imdb,
      label: media.title + ' (' + media.year + ')'
    };
  };

  router.get('/api/v1/suggestions', function (req, res) {
    trakt.search(req.query.title, req.query.type).then(function (data) {
      res.json(data.map(function (media) {
        return formatSuggestion(media[req.query.type]);
      }));
    })['catch'](function () {
      return res.json([]);
    });
  });

  var reportCache = undefined;

  router.get('/api/v1/report', function (req, res, next) {
    if (reportCache) {
      res.json(reportCache);
    } else {
      trakt.getReport().then(function (_) {
        reportCache = _;
        res.json(_);
      })['catch'](function (err) {
        return next(err);
      });
    }
  });

  return router;
};

module.exports = exports['default'];
//# sourceMappingURL=index.js.map