'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.unregisterKeys = exports.unregisterEvents = exports.registerKeys = exports.registerEvents = undefined;

var _storage = require('./storage');

var _storage2 = _interopRequireDefault(_storage);

var _constants = require('./constants');

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _x = require('x11');

var _x2 = _interopRequireDefault(_x);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var noKeyModifier = 0;
// const ctrlKeyModifier = 4;

var playerEvents = {};
var globalEvents = {};
var keyPressEvents = {};

playerEvents[52] = _constants.USER_SCREENSHOT; // z

keyPressEvents[10] = _constants.OMX_KEYS.decreaseSpeed; // 1
keyPressEvents[11] = _constants.OMX_KEYS.increaseSpeed; // 2
keyPressEvents[44] = _constants.OMX_KEYS.previousAudioStream; // j
keyPressEvents[45] = _constants.OMX_KEYS.nextAudioStream; // k
keyPressEvents[32] = _constants.OMX_KEYS.nextChapter; // o

keyPressEvents[57] = _constants.OMX_KEYS.previousSubtitleStream; // n
keyPressEvents[58] = _constants.OMX_KEYS.nextSubtitleStream; // m
keyPressEvents[39] = _constants.OMX_KEYS.toggleSubtitles; // s
keyPressEvents[40] = _constants.OMX_KEYS.decreaseSubtitleDelay; // d
keyPressEvents[41] = _constants.OMX_KEYS.increaseSubtitleDelay; // f

keyPressEvents[33] = _constants.OMX_KEYS.pause; // p
keyPressEvents[65] = _constants.OMX_KEYS.pause; // space
keyPressEvents[24] = _constants.OMX_KEYS.stop; // q
keyPressEvents[9] = _constants.OMX_KEYS.stop; // esc

keyPressEvents[20] = _constants.OMX_KEYS.decreaseVolume; // -
keyPressEvents[112] = _constants.OMX_KEYS.increaseVolume; // pgdn
keyPressEvents[21] = _constants.OMX_KEYS.increaseVolume; // +
keyPressEvents[117] = _constants.OMX_KEYS.decreaseVolume; // pgup

keyPressEvents[113] = _constants.OMX_KEYS.seekBackward;
keyPressEvents[114] = _constants.OMX_KEYS.seekForward;
keyPressEvents[116] = _constants.OMX_KEYS.seekFastBackward;
keyPressEvents[111] = _constants.OMX_KEYS.seekFastForward;

globalEvents[73] = _constants.USER_SCREEN_OFF; // F7
globalEvents[74] = _constants.USER_OPEN_BROWSER; // F8

var pointerMode = false;
var keyboardMode = true;

var X = undefined;
var root = undefined;

var grabKeys = function grabKeys(events) {
	_lodash2.default.map(events, function (event, key) {
		X.GrabKey(root, 0, noKeyModifier, key, pointerMode, keyboardMode);
	});
};

var registerEvents = exports.registerEvents = function registerEvents(events) {
	if (!X) {
		return new _bluebird2.default(function (resolve, reject) {
			_x2.default.createClient(function (err, display) {
				if (err) {
					reject(err);
				}

				X = display.client;
				root = display.screen[0].root;

				grabKeys(events);
				resolve();
			}).on('event', function (event) {
				var action = playerEvents[event.keycode] || globalEvents[event.keycode] || keyPressEvents[event.keycode];

				console.log(event.name, event.keycode, action);

				if (event.name === 'KeyPress') {
					if (action === keyPressEvents[event.keycode]) {
						_storage2.default.emit(_constants.USER_KEY_PRESS, action);
					} else {
						_storage2.default.emit(action);
					}
				}
			});
		});
	} else {
		grabKeys(events);
		return _bluebird2.default.resolve();
	}
};

var registerKeys = exports.registerKeys = function registerKeys() {
	registerEvents(playerEvents);
	registerEvents(keyPressEvents);
};

registerEvents(globalEvents);

var unregisterEvents = exports.unregisterEvents = function unregisterEvents(events) {
	if (X) {
		_lodash2.default.map(events, function (event, key) {
			X.UngrabKey(root, key, 0);
		});
	}
};

var unregisterKeys = exports.unregisterKeys = function unregisterKeys() {
	unregisterEvents(playerEvents);
	unregisterEvents(keyPressEvents);
};
//# sourceMappingURL=x11.js.map